/// StatefulSetCondition describes the state of a statefulset at a certain point.
class StatefulSetCondition {
  /// The main constructor.
  const StatefulSetCondition({
    this.lastTransitionTime,
    this.message,
    this.reason,
    required this.status,
    required this.type,
  });

  /// Creates a StatefulSetCondition from JSON data.
  StatefulSetCondition.fromJson(Map<String, dynamic> json)
      : this(
          lastTransitionTime: json['lastTransitionTime'] != null
              ? DateTime.tryParse(json['lastTransitionTime'])
              : null,
          message: json['message'],
          reason: json['reason'],
          status: json['status'],
          type: json['type'],
        );

  /// Creates a list of StatefulSetCondition from JSON data.
  static List<StatefulSetCondition> listFromJson(
      Iterable<Map<String, dynamic>> list) {
    return list.map((e) => StatefulSetCondition.fromJson(e)).toList();
  }

  /// Last time the condition transitioned from one status to another.
  final DateTime? lastTransitionTime;

  /// A human readable message indicating details about the transition.
  final String? message;

  /// The reason for the condition's last transition.
  final String? reason;

  /// Status of the condition, one of True, False, Unknown.
  final String status;

  /// Type of statefulset condition.
  final String type;
}
