import 'package:kubernetes/src/generated/apimachinery/pkg/apis/meta/v1/object_meta.dart';
import 'package:kubernetes/src/generated/api/core/v1/limit_range_spec.dart';

/// LimitRange sets resource usage limits for each kind of resource in a Namespace.
class LimitRange {
  /// The main constructor.
  const LimitRange({
    this.apiVersion,
    this.kind,
    this.metadata,
    this.spec,
  });

  /// Creates a LimitRange from JSON data.
  LimitRange.fromJson(Map<String, dynamic> json)
      : this(
          apiVersion: json['apiVersion'],
          kind: json['kind'],
          metadata: json['metadata'] != null
              ? ObjectMeta.fromJson(json['metadata'])
              : null,
          spec: json['spec'] != null
              ? LimitRangeSpec.fromJson(json['spec'])
              : null,
        );

  /// Creates a list of LimitRange from JSON data.
  static List<LimitRange> listFromJson(Iterable<Map<String, dynamic>> list) {
    return list.map((e) => LimitRange.fromJson(e)).toList();
  }

  /// APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
  final String? apiVersion;

  /// Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
  final String? kind;

  /// Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
  final ObjectMeta? metadata;

  /// Spec defines the limits enforced. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
  final LimitRangeSpec? spec;
}
