import 'package:kubernetes/src/generated/api/flowcontrol/v1beta1/flow_distinguisher_method.dart';
import 'package:kubernetes/src/generated/api/flowcontrol/v1beta1/priority_level_configuration_reference.dart';
import 'package:kubernetes/src/generated/api/flowcontrol/v1beta1/policy_rules_with_subjects.dart';

/// FlowSchemaSpec describes how the FlowSchema's specification looks like.
class FlowSchemaSpec {
  /// The main constructor.
  const FlowSchemaSpec({
    this.distinguisherMethod,
    this.matchingPrecedence,
    required this.priorityLevelConfiguration,
    this.rules,
  });

  /// Creates a FlowSchemaSpec from JSON data.
  FlowSchemaSpec.fromJson(Map<String, dynamic> json)
      : this(
          distinguisherMethod: json['distinguisherMethod'] != null
              ? FlowDistinguisherMethod.fromJson(json['distinguisherMethod'])
              : null,
          matchingPrecedence: json['matchingPrecedence'],
          priorityLevelConfiguration:
              PriorityLevelConfigurationReference.fromJson(
                  json['priorityLevelConfiguration']),
          rules: json['rules'] != null
              ? PolicyRulesWithSubjects.listFromJson(
                  (json['rules'] as Iterable).cast<Map<String, dynamic>>())
              : null,
        );

  /// Creates a list of FlowSchemaSpec from JSON data.
  static List<FlowSchemaSpec> listFromJson(
      Iterable<Map<String, dynamic>> list) {
    return list.map((e) => FlowSchemaSpec.fromJson(e)).toList();
  }

  /// `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
  final FlowDistinguisherMethod? distinguisherMethod;

  /// `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
  final int? matchingPrecedence;

  /// `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
  final PriorityLevelConfigurationReference priorityLevelConfiguration;

  /// `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
  final List<PolicyRulesWithSubjects>? rules;
}
